##  Publishing Process
The following image shows the workflow of publishing reports on the SAP LeanIX Store.
To get started and publish your first custom report on the SAP LeanIX Store, register as a publisher, create a report, then initiate the review process. Once your report is published, you can create new report versions.
![Workflow: Publishing Reports on the SAP LeanIX Store](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751edc97a441014a492d1c680f2c540_LowRes.png)
Workflow of Publishing Custom Reports on the SAP LeanIX Store
